==> nextcloud-25.0.13.tar.bz2: nextcloud/apps/photos/l10n/sv.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentlig länk",
    "Photos" : "Bilder",
    "Your memories under your control" : "Dina minnen under din kontroll",
    "All media" : "All media",
    "Videos" : "Videor",
    "Albums" : "Album",
    "Collaborative albums" : "Kollaborativa album",
    "People" : "Personer",
    "Folders" : "Mappar",
    "Favorites" : "Favoriter",
    "On this day" : "På den här dagen",
    "Shared with you" : "Delad med dig",
    "Tags" : "Taggar",
    "Places" : "Platser",
    "Map" : "Karta",
    "Photos settings" : "Inställningar",
    "Mark selection as favorite" : "Markera val som favorit",
    "Add selection to favorites" : "Lägg till val i favoriter",
    "Remove selection from favorites" : "Ta bort val från favoriter",
    "Name of the album" : "Namn på albumet",
    "Location of the album" : "Albumets plats",
    "Back" : "Tillbaka",
    "Add collaborators" : "Lägg till medlemmar",
    "Save" : "Spara",
    "Create album" : "Skapa album",
    "Add to Album" : "Lägg till i album",
    "Add selection to album {albumName}" : "Lägg till urval för {albumName}",
    "Shared by" : "Delad av",
    "Create a new album." : "Skapa ett nytt album.",
    "Create new album" : "Skapa nytt album",
    "New album" : "Nytt album",
    "_%n item_::_%n photos and videos_" : ["Ett objekt","%n bilder och videor"],
    "Add people or groups who can edit your album" : "Lägg till personer eller grupper som kan redigera ditt album",
    "Search people or groups" : "Sök personer eller grupper",
    "No recommendations. Start typing." : "Inga rekommendationer. Börja skriva.",
    "Group" : "Grupp",
    "Remove {collaboratorLabel} from the collaborators list" : "Ta bort {collaboratorLabel} från medlemslistan",
    "Copy the public link" : "Kopiera den offentliga länken",
    "Public link copied!" : "Offentlig länk kopierad!",
    "Copy public link" : "Kopiera offentlig länk",
    "Delete the public link" : "Ta bort den offentliga länken",
    "Create public link share" : "Skapa publik delningslänk",
    "Share via public link" : "Dela via offentlig länk",
    "Failed to fetch collaborators list." : "Det gick inte att hämta medlemslistan.",
    "Failed to update album." : "Misslyckades att uppdatera album.",
    "This collection does not exist" : "Den här samlingen existerar ej",
    "An error occurred" : "Ett fel uppstod",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ej tilldelat foto","%n ej tilldelade foton"],
    "Select image {imageName}" : "Välj bild {imageName}",
    "The file is in the favorites" : "Filen finns bland favoriterna",
    "Open the full size \"{name}\" image" : "Öppna bilden \"{name}\" i full storlek",
    "There are no photos or videos yet!" : "Det finns inga bilder eller videor än!",
    "Add to {destination}" : "Lägg till i {destination}",
    "Open the \"{name}\" sub-directory" : "Öppna undermappen \"{name}\"",
    "Back to {folder}" : "Tillbaka till {folder}",
    "Share this folder" : "Dela denna mapp",
    "_{years} year ago_::_{years} years ago_" : ["{years} år sedan","{years} år sedan"],
    "Enable squared photos view" : "Aktivera kvadratiska bild-vyn",
    "Default Photos upload and Albums location" : "Standardplats för album och bilder",
    "Choose default Photos upload and Albums location" : "Välj standardplats uppladdning av bilder och plats för album",
    "Select the default location for your media" : "Välj standardplats för din media",
    "Invalid location selected" : "Ogiltig plats vald",
    "View" : "Visa",
    "Photos directory" : "Bildmapp",
    "_%n photo_::_%n photos_" : ["%n bild","%n bilder"],
    "Unselect all" : "Avmarkera alla",
    "Manage collaborators for this album" : "Hantera medlemmar för det här albumet",
    "Open actions menu" : "Öppna åtgärdsmenyn",
    "Edit album details" : "Ändra albumdetaljer",
    "Download all files in album" : "Ladda ner alla filer i albumet",
    "Delete album" : "Radera album",
    "Download selected files" : "Ladda ner de markerade filerna",
    "Remove selection from album" : "Ta bort urval från album",
    "This album does not have any photos or videos yet!" : "Det här albumet har inga bilder eller videor än!",
    "Add photos to this album" : "Lägg till bilder i detta album",
    "Add photos to {albumName}" : "Lägg till bilder i {albumName}",
    "Manage collaborators" : "Hantera medlemmar",
    "Save collaborators for this album." : "Spara medlemmar för det här albumet.",
    "Cover photo for album {albumName}" : "Omslagsbild för albumet {albumName}",
    "There is no album yet!" : "Det finns inget album ännu!",
    "This person could not be found" : "Personen kunde inte hittas",
    "Rename person" : "Byt namn på person",
    "Merge with different person" : "Slå ihop med en annan person",
    "Download selected photos" : "Ladda ner de markerade bilderna",
    "Favorite" : "Favorit",
    "Remove from favorites" : "Ta bort från favoriter",
    "Remove person" : "Ta bort person",
    "Name of this person" : "Denna persons namn",
    "Save." : "Spara.",
    "Merge person" : "Slå samman person",
    "Move to different person" : "Flytta till en annan person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Flytta bild till en annan person","Flytta bilder till en annan person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Ta bort bild från personen","Ta bort bilder från person"],
    "This might take some time depending on the size of your photo library." : "Detta kan ta lite tid beroende på storleken på ditt bildbibliotek.",
    "Recognized people will show up here" : "Personer som är identifierade kommer att synas här",
    "This folder does not exist" : "Denna mappen finns inte",
    "Loading folders …" : "Laddar mappar...",
    "No photos in here" : "Det finns inga bilder här",
    "This place does not have any photos or videos yet!" : "Den här platsen har inga bilder eller videor än!",
    "Add photos to this place" : "Lägg till bilder till denna plats",
    "Cover photo for place {placeName}" : "Omslagsbild för plats {placeName}",
    "There is no place yet!" : "Det finns ingen plats ännu!",
    "Cover photo for shared album {albumName}." : "Omslagsbild för delat album {albumName}.",
    "Back to tags overview" : "Tillbaka till tagg-översikten",
    "No photos with this tag yet" : "Inga bilder med denna tagg ännu",
    "No tags yet" : "Inga taggar än",
    "Photos with tags will show up here" : "Bilder med taggar visas här",
    "Popular tags" : "Populära taggar",
    "Add" : "Lägg till",
    "Add to album" : "Lägg till i album",
    "Delete selection" : "Ta bort urval",
    "No photos or videos in here" : "Inga bilder eller videos här",
    "Unassigned faces" : "Ej tilldelade ansikten",
    "_%n photos_::_%n photos_" : ["%n bild","%n bilder"],
    "Failed to fetch collection." : "Det gick inte att hämta samlingen.",
    "Failed to fetch collections list." : "Det gick inte att hämta samlingslistan.",
    "Failed to fetch faces list." : "Lyckades inte hämta lista på ansikte",
    "All your media" : "All din media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Delade Album",
    "Shared album {title}" : "Delat album {title}",
    "Public album {title}" : "Offentligt album {title}",
    "Tagged photos" : "Taggade bilder",
    "Tagged photo {title}" : "Taggad bild {title}",
    "{title}'s face" : "{title}s ansikte",
    "{startDate} to {endDate}" : "{startDate} till {endDate}",
    "Failed to rename {oldName} to {faceName}." : "Lyckades inte döpa om {oldName} till {faceName}.",
    "Failed to delete {faceName}." : "Misslyckades att radera {faceName}.",
    "Failed to delete {fileId}." : "Misslyckades att radera {fileId}.",
    "Failed to delete {fileName}." : "Misslyckades att radera {fileName}.",
    "Failed to set favorite state for {fileId}." : "Det gick inte att ange favoritstatus för {fileId}.",
    "Failed to set favorite state for {fileName}." : "Det gick inte att ange favoritstatus för {fileName}.",
    "Locations" : "Platser",
    "Go back to the previous view." : "Gå tillbaka till föregående vy",
    "Go to the add collaborators view." : "Gå till vyn lägg till medlemmar.",
    "Create the album." : "Skapa albumet.",
    "Back to the new album form." : "Tillbaka till nytt album formuläret.",
    "_Share with %n user_::_Share with %n users_" : ["Dela med en användare","Dela med %n användare"],
    "Search for collaborators" : "Sök efter medlemmar",
    "Add {collaboratorLabel} to the collaborators list" : "Lägg till {collaboratorLabel} i listan med medlemmar",
    "No collaborators available" : "Inga medlemmar är tillgängliga",
    "Failed to fetch album." : "Misslyckades att hämta album.",
    "Add photos to the album" : "Lägg till bilder i albumet",
    "Failed to fetch albums list." : "Misslyckades att hämta albumlistan.",
    "Shared albums" : "Delade album",
    "Create a new album" : "Skapa ett nytt album",
    "Add selection to an album" : "Lägg till urval till ett album",
    "Failed to create {albumName}." : "Lyckades inte skapa {albumName}.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "Lyckades inte döpa om {currentAlbumName} till {newAlbumName}."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.14.tar.bz2: nextcloud/apps/photos/l10n/sv.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Offentlig länk",
    "Photos" : "Bilder",
    "On This Day" : "På denna dag",
    "Your memories under your control" : "Dina minnen under din kontroll",
    "All media" : "All media",
    "Videos" : "Videor",
    "Albums" : "Album",
    "Collaborative albums" : "Kollaborativa album",
    "People" : "Personer",
    "Folders" : "Mappar",
    "Favorites" : "Favoriter",
    "On this day" : "På den här dagen",
    "Shared with you" : "Delad med dig",
    "Tags" : "Taggar",
    "Places" : "Platser",
    "Map" : "Karta",
    "Photos settings" : "Inställningar",
    "Mark selection as favorite" : "Markera val som favorit",
    "Add selection to favorites" : "Lägg till val i favoriter",
    "Remove selection from favorites" : "Ta bort val från favoriter",
    "Name of the album" : "Namn på albumet",
    "Location of the album" : "Albumets plats",
    "Back" : "Tillbaka",
    "Add collaborators" : "Lägg till medlemmar",
    "Save" : "Spara",
    "Create album" : "Skapa album",
    "Add to Album" : "Lägg till i album",
    "Add selection to album {albumName}" : "Lägg till urval för {albumName}",
    "Shared by" : "Delad av",
    "Create a new album." : "Skapa ett nytt album.",
    "Create new album" : "Skapa nytt album",
    "New album" : "Nytt album",
    "_%n item_::_%n photos and videos_" : ["Ett objekt","%n bilder och videor"],
    "Failed to fetch collaborators list." : "Det gick inte att hämta medlemslistan.",
    "Failed to update album." : "Misslyckades att uppdatera album.",
    "Add people or groups who can edit your album" : "Lägg till personer eller grupper som kan redigera ditt album",
    "Search people or groups" : "Sök personer eller grupper",
    "No recommendations. Start typing." : "Inga rekommendationer. Börja skriva.",
    "Group" : "Grupp",
    "Remove {collaboratorLabel} from the collaborators list" : "Ta bort {collaboratorLabel} från medlemslistan",
    "Copy the public link" : "Kopiera den offentliga länken",
    "Public link copied!" : "Offentlig länk kopierad!",
    "Copy public link" : "Kopiera offentlig länk",
    "Delete the public link" : "Ta bort den offentliga länken",
    "Create public link share" : "Skapa publik delningslänk",
    "Share via public link" : "Dela via offentlig länk",
    "This collection does not exist" : "Den här samlingen existerar ej",
    "An error occurred" : "Ett fel uppstod",
    "No picture for this day" : "Ingen bild för denna dag",
    "Picture taken on this day will show up here." : "Bild tagen den här dagen kommer att dyka upp här.",
    "More photos from this day" : "Fler bilder från denna dag",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ej tilldelat foto","%n ej tilldelade foton"],
    "Favorite" : "Favorit",
    "Favorite image, open the full size \"{name}\" image" : "Favoritbild, öppna bilden \"{name}\" i full storlek",
    "Open the full size \"{name}\" image" : "Öppna bilden \"{name}\" i full storlek",
    "Select image {imageName}" : "Välj bild {imageName}",
    "Open the \"{name}\" folder" : "Öppna mappen \"{name}\"",
    "Back to {folder}" : "Tillbaka till {folder}",
    "Go back" : "Gå tillbaks",
    "Share this folder" : "Dela denna mapp",
    "Dates" : "Datum",
    "Jump to specific date in list" : "Hoppa till specifikt datum i listan",
    "Jump to {date}" : "Gå till {date}",
    "Add to {destination}" : "Lägg till i {destination}",
    "The destination folder is owned by {owner}" : "Målmappen ägs av {owner}",
    "There are no photos or videos yet!" : "Det finns inga bilder eller videor än!",
    "_{years} year ago_::_{years} years ago_" : ["{years} år sedan","{years} år sedan"],
    "Enable squared photos view" : "Aktivera kvadratiska bild-vyn",
    "Delete source directory" : "Ta bort källkatalog",
    "Pick folder" : "Välj mapp",
    "Select a source folder for your media" : "Välj en källmapp för ditt media",
    "All folders" : "Alla mappar",
    "Add a Photos source for the timelines" : "Lägg till en fotokälla för tidslinjerna",
    "Add folder" : "Lägg till mapp",
    "Select the default upload location for your media" : "Välj standarduppladdningsplats för ditt media",
    "Home" : "Hem",
    "Choose default Photos upload and Albums location" : "Välj standardplats uppladdning av bilder och plats för album",
    "Choose a different folder" : "Välj annan mapp",
    "View" : "Visa",
    "Media folders" : "Mediamappar",
    "Choose the folders from where photos and videos are shown." : "Välj mappar där foton och videor ska visas från.",
    "Upload folder" : "Ladda upp mapp",
    "Choose the folder where photos and albums are uploaded to." : "Välj mapp dit foton och album laddas upp.",
    "_%n photo_::_%n photos_" : ["%n bild","%n bilder"],
    "Unselect all" : "Avmarkera alla",
    "Add photos to this album" : "Lägg till bilder i detta album",
    "Manage collaborators for this album" : "Hantera medlemmar för det här albumet",
    "Open actions menu" : "Öppna åtgärdsmenyn",
    "Edit album details" : "Ändra albumdetaljer",
    "Download all files in album" : "Ladda ner alla filer i albumet",
    "Delete album" : "Radera album",
    "Download selected files" : "Ladda ner de markerade filerna",
    "Remove selection from album" : "Ta bort urval från album",
    "This album does not have any photos or videos yet!" : "Det här albumet har inga bilder eller videor än!",
    "Add photos to {albumName}" : "Lägg till bilder i {albumName}",
    "Manage collaborators" : "Hantera medlemmar",
    "Save collaborators for this album." : "Spara medlemmar för det här albumet.",
    "Cover photo for album {albumName}" : "Omslagsbild för albumet {albumName}",
    "There is no album yet!" : "Det finns inget album ännu!",
    "This person could not be found" : "Personen kunde inte hittas",
    "Rename person" : "Byt namn på person",
    "Merge with different person" : "Slå ihop med en annan person",
    "Download selected photos" : "Ladda ner de markerade bilderna",
    "Remove from favorites" : "Ta bort från favoriter",
    "Remove person" : "Ta bort person",
    "Name of this person" : "Denna persons namn",
    "Save." : "Spara.",
    "Merge person" : "Slå samman person",
    "Move to different person" : "Flytta till en annan person",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Flytta bild till en annan person","Flytta bilder till en annan person"],
    "_Remove photo from person_::_Remove photos from person_" : ["Ta bort bild från personen","Ta bort bilder från person"],
    "This might take some time depending on the size of your photo library." : "Detta kan ta lite tid beroende på storleken på ditt bildbibliotek.",
    "Recognized people will show up here" : "Personer som är identifierade kommer att synas här",
    "This folder does not exist" : "Denna mappen finns inte",
    "Loading folders …" : "Laddar mappar...",
    "No photos in here" : "Det finns inga bilder här",
    "Taken on {date} at {time}" : "Tagen den {date} kl. {time}",
    "This place does not have any photos or videos yet!" : "Den här platsen har inga bilder eller videor än!",
    "Add photos to this place" : "Lägg till bilder till denna plats",
    "Cover photo for place {placeName}" : "Omslagsbild för plats {placeName}",
    "There is no place yet!" : "Det finns ingen plats ännu!",
    "Cover photo for shared album {albumName}." : "Omslagsbild för delat album {albumName}.",
    "Back to tags overview" : "Tillbaka till tagg-översikten",
    "No photos with this tag yet" : "Inga bilder med denna tagg ännu",
    "No tags yet" : "Inga taggar än",
    "Photos with tags will show up here" : "Bilder med taggar visas här",
    "Popular tags" : "Populära taggar",
    "All tags" : "Alla taggar",
    "One of the source folders does not exist" : "En av källmapparna finns inte",
    "Add to album" : "Lägg till i album",
    "Delete selection" : "Ta bort urval",
    "No photos or videos in here" : "Inga bilder eller videos här",
    "Unassigned faces" : "Ej tilldelade ansikten",
    "_%n photos_::_%n photos_" : ["%n bild","%n bilder"],
    "Failed to fetch collection." : "Det gick inte att hämta samlingen.",
    "Failed to fetch collections list." : "Det gick inte att hämta samlingslistan.",
    "Failed to fetch faces list." : "Lyckades inte hämta lista på ansikte",
    "All your media" : "All din media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Delade Album",
    "Shared album {title}" : "Delat album {title}",
    "Public album {title}" : "Offentligt album {title}",
    "Tagged photos" : "Taggade bilder",
    "Tagged photo {title}" : "Taggad bild {title}",
    "{title}'s face" : "{title}s ansikte",
    "{startDate} to {endDate}" : "{startDate} till {endDate}",
    "Details" : "Detaljer",
    "Failed to rename {oldName} to {faceName}." : "Lyckades inte döpa om {oldName} till {faceName}.",
    "Failed to delete {faceName}." : "Misslyckades att radera {faceName}.",
    "Failed to delete {fileId}." : "Misslyckades att radera {fileId}.",
    "Failed to delete {fileName}." : "Misslyckades att radera {fileName}.",
    "Failed to set favorite state for {fileId}." : "Det gick inte att ange favoritstatus för {fileId}.",
    "Failed to set favorite state for {fileName}." : "Det gick inte att ange favoritstatus för {fileName}.",
    "Could not load photos folder" : "Kunde inte ladda fotomappen",
    "One of the source folders does not exists" : "En av källmapparna finns inte",
    "Add" : "Lägg till"
},
"nplurals=2; plural=(n != 1);");
